diff --git a/library/ui/src/main/res/drawable/exo_rounded_rectangle.xml b/library/ui/src/main/res/drawable/exo_rounded_rectangle.xml
new file mode 100644
index 0000000000..c5bbb6ecc3
--- /dev/null
+++ b/library/ui/src/main/res/drawable/exo_rounded_rectangle.xml
@@ -0,0 +1,19 @@
+
+
+
+
+
+
diff --git a/library/ui/src/main/res/layout/exo_styled_player_control_view.xml b/library/ui/src/main/res/layout/exo_styled_player_control_view.xml
index c869beac43..083ce48d06 100644
--- a/library/ui/src/main/res/layout/exo_styled_player_control_view.xml
+++ b/library/ui/src/main/res/layout/exo_styled_player_control_view.xml
@@ -26,7 +26,7 @@
android:layout_width="match_parent"
android:layout_height="match_parent"
android:layout_gravity="center"
- android:background="@color/exo_widget_center_view_background" />
+ android:background="@color/exo_black_opacity_30" />
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/library/ui/src/main/res/values/colors.xml b/library/ui/src/main/res/values/colors.xml
index b22eea9427..b27a13e924 100644
--- a/library/ui/src/main/res/values/colors.xml
+++ b/library/ui/src/main/res/values/colors.xml
@@ -20,6 +20,7 @@
#ffffff
#B3ffffff
#B3000000
- #90000000
+ #4D000000
+ #80808080
#b0000000
diff --git a/library/ui/src/main/res/values/dimens.xml b/library/ui/src/main/res/values/dimens.xml
index 756baca310..65f107602e 100644
--- a/library/ui/src/main/res/values/dimens.xml
+++ b/library/ui/src/main/res/values/dimens.xml
@@ -42,4 +42,10 @@
10dp
170sp
+
+ 32dp
+ 64dp
+ 14sp
+ 12dp
+ 4dp
diff --git a/library/ui/src/main/java/com/google/android/exoplayer2/ui/StyledPlayerView.java b/library/ui/src/main/java/com/google/android/exoplayer2/ui/StyledPlayerView.java
index b89cdbf937..8b6c5983c6 100644
--- a/library/ui/src/main/java/com/google/android/exoplayer2/ui/StyledPlayerView.java
+++ b/library/ui/src/main/java/com/google/android/exoplayer2/ui/StyledPlayerView.java
@@ -192,10 +192,10 @@ import org.checkerframework.checker.nullness.qual.RequiresNonNull;
*
Overriding the layout file
*
* To customize the layout of StyledPlayerView throughout your app, or just for certain
* configurations, you can define {@code exo_player_view.xml} layout files in your application
* {@code res/layout*} directories. These layouts will override the one provided by the ExoPlayer
* library, and will be inflated for use by StyledPlayerView. The view identifies and binds its
* children by looking for the following ids:
*
*
* - {@code exo_content_frame} - A frame whose aspect ratio is resized based on the video
@@ -365,7 +365,7 @@ public class StyledPlayerView extends FrameLayout implements AdsLoader.AdViewPro
boolean shutterColorSet = false;
int shutterColor = 0;
- int playerLayoutId = R.layout.exo_player_view;
+ int playerLayoutId = R.layout.exo_styled_player_view;
boolean useArtwork = true;
int defaultArtworkId = 0;
boolean useController = true;
@@ -192,10 +192,10 @@ import org.checkerframework.checker.nullness.qual.RequiresNonNull;
*
* To customize the layout of StyledPlayerView throughout your app, or just for certain
- * configurations, you can define {@code exo_player_view.xml} layout files in your application
- * {@code res/layout*} directories. These layouts will override the one provided by the ExoPlayer
- * library, and will be inflated for use by StyledPlayerView. The view identifies and binds its
- * children by looking for the following ids:
+ * configurations, you can define {@code exo_styled_player_view.xml} layout files in your
+ * application {@code res/layout*} directories. These layouts will override the one provided by the
+ * ExoPlayer library, and will be inflated for use by StyledPlayerView. The view identifies and
+ * binds its children by looking for the following ids:
*
*